@@ -2,9 +2,9 @@ try:
     from libtbx import Auto
     from libtbx.utils import Sorry
 except ModuleNotFoundError:
-    from .legacy import AutoType
+    from .legacy import AutoType as _AutoType
 
-    Auto = AutoType()
+    Auto = _AutoType()
 
     class Sorry(SystemExit):
         pass
@@ -12,4 +12,4 @@ except ModuleNotFoundError:
 
 from .common import *  # noqa
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
